<?php

/* Reminder: always indent with 4 spaces (no tabs). */
// +---------------------------------------------------------------------------+
// | Manual Digest Plugin 1.3                                                  |
// +---------------------------------------------------------------------------+
// | install.php                                                               |
// |                                                                           |
// | This file installs and removes the data structures for the Manual Digest  |
// | plugin for Geeklog.                                                       |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2003-2009 by the following authors:                         |
// |                                                                           |
// | Authors: Dirk Haun <dirk AT haun-online DOT de>                           |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+
//
// $Id: install.php,v 1.7 2009/03/08 15:01:59 dhaun Exp $

require_once('../../../lib-common.php');
require_once($_CONF['path'] . 'plugins/mdigest/functions.inc');

// Only let Root users access this page
if (!SEC_inGroup ('Root')) {
    // Someone is trying to illegally access this page
    COM_accessLog ("Someone has tried to illegally access the Manual Digest install/uninstall page.  User id: {$_USER['uid']}, Username: {$_USER['username']}, IP: $REMOTE_ADDR",1);
    $display = COM_siteHeader();
    $display .= COM_startBlock($LANG_MDIGEST['access_denied']);
    $display .= $LANG_MDIGEST['access_denied_msg'];
    $display .= COM_endBlock();
    $display .= COM_siteFooter();
    echo $display;
    exit;
}

function plugin_install_mdigest()
{
    global $_TABLES, $_CONF;

    COM_errorLog ('Attempting to install the Manual Digest Plugin', 1);

    // Register the plugin with Geeklog
    if (DB_count ($_TABLES['plugins'], 'pi_name', 'mdigest') > 0) {
        COM_errorLog ('Attempting to remove mdigest entry prior to adding an updated entry', 1);
        DB_query("DELETE FROM {$_TABLES['plugins']} WHERE pi_name = 'mdigest'");
        if (DB_error()) {
            plugin_uninstall_mdigest ();
            return false;
        }
        COM_errorLog ('...success', 1);
    } else {
        // Only install data on a fresh installation
        // This plugin has no install data
    }

    COM_errorLog ('Registering Manual Digest plugin with Geeklog', 1);
    DB_delete ($_TABLES['plugins'], 'pi_name', 'mdigest');
    DB_query ("INSERT INTO {$_TABLES['plugins']} (pi_name, pi_version, pi_gl_version, pi_homepage, pi_enabled) VALUES ('mdigest', '1.3.1', '1.3.7', 'http://geeklog.info/', 1)");

    if (DB_error()) {
        plugin_uninstall_mdigest();
        return false;
    }

    COM_errorLog('...success',1);
    COM_errorLog('Succesfully installed the Manual Digest Plugin!',1);

    return true;
}


$display = COM_siteHeader();

if (DB_count ($_TABLES['vars'], 'name', 'mdigest') == 0) {
    // Record in vars table doesn' exit, install this plugin
    if (plugin_install_mdigest ()) {
        echo COM_refresh ($_CONF['site_admin_url'] . '/plugins.php?msg=44');
        exit;
    } else {
        // Error occured
        $display .= COM_startBlock($LANG_MDIGEST['installation_failed']);
        $display .= $LANG_MDIGEST['installation_failed_msg'];
        $display .= COM_endBlock();
    }   
} else {
    // Uninstall plugin
    if (plugin_uninstall_mdigest()) {
        // Uninstall worked
        echo COM_refresh ($_CONF['site_admin_url'] . '/plugins.php?msg=45');
        exit;
    } else {
        // Uninstall failed
        $display .= COM_startBlock($LANG_MDIGEST['uninstall_failed']);
        $display .= $LANG_MDIGEST['uninstall_failed_msg'];
        $display .= COM_endBlock();
    }
}

$display .= COM_siteFooter();

echo $display;

?>
